================
 zerodbext.catalog
================

A Python indexing and searching system based on `zope.index`_, fork of `repoze.catalog`_.

.. _`zope.index`: https://pypi.python.org/pypi/zope.index
.. _`repoze.catalog`: https://pypi.python.org/pypi/repoze.catalog

Important changes include dependency cleanup and Python3 support: thanks to micxjo
